@@ -1,8 +1,6 @@
-"""Theil Inequality metrics
+"""Theil Inequality metrics"""
 
-"""
-
-__author__ = "Sergio J. Rey <srey@asu.edu> "
+__author__ = "Sergio J. Rey <srey@sdsu.edu>"
 
 import numpy
 
@@ -144,7 +142,8 @@ class TheilD:
         ng.shape = (ng.size,)  # ensure ng is 1-d
         n = y.shape[0]
         # between group inequality
-        sg = sg + (sg == 0)  # handle case when a partition has 0 for sum
+        sg = sg + SMALL * (sg == 0)  # can't have 0 values
+
         bg = numpy.multiply(sg, numpy.log(numpy.dot(numpy.diag(n * 1.0 / ng), sg))).sum(
             axis=0
         )
